---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: issue type - bug, triage
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Run this code: '...'
2. See error: '....'

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - OS: [e.g. Debian]
 - Python version [e.g. 3.10.8]
 - pyfoxhole package version [e.g. v0.0.6 or 83923e1]

**Additional context**
Add any other context about the problem here.
